summaryrefslogtreecommitdiffstats
path: root/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/components/debugger/dbgp/qbytearrayfifo.cpp')
-rw-r--r--quanta/components/debugger/dbgp/qbytearrayfifo.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/quanta/components/debugger/dbgp/qbytearrayfifo.cpp b/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
index 4f8e72d8..6a52ac39 100644
--- a/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
+++ b/quanta/components/debugger/dbgp/qbytearrayfifo.cpp
@@ -21,13 +21,13 @@
#include <tqcstring.h>
#include <kmdcodec.h>
-QByteArrayFifo::QByteArrayFifo( )
+TQByteArrayFifo::TQByteArrayFifo( )
{
m_size = 0;
m_array.resize(0);
}
-TQString QByteArrayFifo::retrieve( )
+TQString TQByteArrayFifo::retrieve( )
{
// See if there's a null teminator somewhere
TQString str(m_array);
@@ -38,16 +38,16 @@ TQString QByteArrayFifo::retrieve( )
for(size_t cnt = 0; cnt < m_size; cnt++)
m_array[cnt] = m_array[cnt + size];
// Resize array, needed for find() to work
m_array.resize(m_size);
return str;
}
-bool QByteArrayFifo::append(const char * chars, size_t size )
+bool TQByteArrayFifo::append(const char * chars, size_t size )
{
// Resize the array, fail if not possible
- if(!m_array.resize(m_size + size ))
+ if(!m_array.tqresize(m_size + size ))
return false;
// Copy the elements
@@ -60,16 +60,16 @@ bool QByteArrayFifo::append(const char * chars, size_t size )
return true;
}
-long QByteArrayFifo::find( char character )
+long TQByteArrayFifo::tqfind( char character )
{
// If size is 0, find() outputs a warning for some reason
if(m_size == 0)
return -1;
- return m_array.find(character);
+ return m_array.tqfind(character);
}
-TQString QByteArrayFifo::base64Encoded()
+TQString TQByteArrayFifo::base64Encoded()
{
return KCodecs::base64Encode(m_array);
}
@@ -38,16 +38,16 @@ TQString QByteArrayFifo::retrieve( )
for(size_t cnt = 0; cnt < m_size; cnt++)
m_array[cnt] = m_array[cnt + size];
- // Resize array, needed for find() to work
+ // Resize array, needed for tqfind() to work
m_array.resize(m_size);
return str;
@@ -60,16 +60,16 @@ bool QByteArrayFifo::append(const char * chars, size_t size )
{
- // If size is 0, find() outputs a warning for some reason
+ // If size is 0, tqfind() outputs a warning for some reason
if(m_size == 0)
return -1;